@@ -38,11 +38,17 @@ manager::manager()
     msg << getpid();
     msg << getSetting("interval","600").toInt();
     QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
-    qDebug()<<reply;
 
     QDBusConnection sessionConnection = QDBusConnection::sessionBus();
     sessionConnection.connect("", "/proximityd/signal/state", "proximityd.signal.state", "changed", this, SLOT(printTime(QString)));
 
+    keepTkLockOn = new QTimer(this);
+    keepTkLockOn->setSingleShot(true);
+    keepTkLockOn->setInterval(getSetting("timeout","8000").toInt());
+    pressPowerTimer = new QTimer(this);
+    pressPowerTimer->setInterval(4100);
+    connect(keepTkLockOn, SIGNAL(timeout()), this, SLOT(off()));
+    connect(pressPowerTimer, SIGNAL(timeout()), this, SLOT(pressPower()));
 //    timerOff = new QTimer(this);
 //    connect(timerOff, SIGNAL(timeout()), this, SLOT(off()));
 //    timer = new QTimer(this);
@@ -69,13 +75,13 @@ QDBusMessage manager::modifyProximitydState(QString newState){
          msg << newState;
          msg << getpid();
          QDBusMessage reply = QDBusConnection::sessionBus().call(msg);
-         qDebug()<<reply;
+//         qDebug()<<reply;
     }
     return msg;
 }
 
 void manager::controlPolling(QDBusMessage& reply){
-    qDebug("checking");
+//    qDebug("checking");
     QString status = reply.arguments().value(0).value<QString>();
     controlPolling(status);
 }
@@ -86,20 +92,58 @@ void manager::controlPolling(QString status){
     } else {
         modifyProximitydState("turnOff");
 //        killEverybody();
-        qDebug("unlocked");
     }
 }
 
+void manager::setLockScreenMode(QString mode){
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+            "com.nokia.mce", // --dest
+            "/com/nokia/mce/request", // destination object path
+            "com.nokia.mce.request", // message name (w/o method)
+            "req_tklock_mode_change" // method
+        );
+         msg << mode;
+         QDBusMessage reply = QDBusConnection::systemBus().call(msg);
+//         qDebug()<<reply;
+
+}
+
+void manager::setDisplayMode(QString mode){
+    QDBusMessage msg = QDBusMessage::createMethodCall(
+            "com.nokia.mce", // --dest
+            "/com/nokia/mce/request", // destination object path
+            "com.nokia.mce.request", // message name (w/o method)
+            "req_display_state_" + mode // method
+        );
+         msg << mode;
+         QDBusMessage reply = QDBusConnection::systemBus().call(msg);
+}
+
+void manager::pressPower(){
+    QProcess::startDetached( "/opt/timenowd/bin/shcript", QStringList() << " " );
+}
+
 void manager::printTime(QString state){
-    qDebug("stateChanged");
-    if (checkIfLockedAndBlank()&&state=="open"){
-          QProcess::startDetached( "/opt/timenowd/bin/shcript", QStringList() << " " );
+//    if (!checkIfLockedAndBlank())
+    if (state=="open"){
+        if (checkIfLockedAndBlank()){
+            qDebug()<<"let's start dancing";
+            pressPowerTimer->start();
+            keepTkLockOn->start();
+            pressPower();
+        }
     } else {
-
+        qDebug()<<"stop and lock";
+        pressPowerTimer->stop();
+        keepTkLockOn->stop();
+        if (checkIfLocked()) setDisplayMode("off");
     }
+
 }
 
 void manager::off(){
+    pressPowerTimer->stop();
+    qDebug()<<"enough";
     if (checkIfLockedAndBlank()){
         QProcess::startDetached( "/opt/timenowd/bin/shcriptoff", QStringList() << " " );
     }
@@ -134,14 +178,18 @@ bool manager::checkIfLockedAndBlank(){
     const QDBusMessage& reply = mceInterface->call(MCE_DISPLAY_STATUS_GET);
     QString display = reply.arguments().value(0).value<QString>();
 
-    const QDBusMessage& reply2 = mceInterface->call(MCE_TKLOCK_MODE_GET);
-    QString locked = reply2.arguments().value(0).value<QString>();
-
-    if (display == MCE_DISPLAY_OFF_STRING && locked == MCE_TK_LOCKED){
+    if (display == MCE_DISPLAY_OFF_STRING && checkIfLocked()){
         return true;
     } else return false;
 }
 
+bool manager::checkIfLocked(){
+    const QDBusMessage& reply2 = mceInterface->call(MCE_TKLOCK_MODE_GET);
+    QString locked = reply2.arguments().value(0).value<QString>();
+    qDebug()<<locked;
+    return (locked == MCE_TK_LOCKED);
+}
+
 
 void manager::sleep(int ms)
 {
